@@ -22,28 +22,24 @@
  */
 
 #include <config.h>
-#include <gtk/gtkobject.h>
-#include <gtk/gtksignal.h>
 #include "e-table-col.h"
 #include "gal/util/e-util.h"
-
-#define PARENT_TYPE (gtk_object_get_type ())
+#include "gal/util/e-i18n.h"
 
 static GObjectClass *parent_class;
 
-
 enum {
-	ARG_0,
-	ARG_SORTABLE
+	PROP_0,
+	PROP_COMPARE_COL,
 };
 
 static void
-etc_finalize (GObject *object)
+etc_dispose (GObject *object)
 {
 	ETableCol *etc = E_TABLE_COL (object);
 
 	if (etc->ecell)
-		gtk_object_unref (GTK_OBJECT(etc->ecell));
+		g_object_unref (etc->ecell);
 	etc->ecell = NULL;
 
 	if (etc->pixbuf)
@@ -54,47 +50,53 @@ etc_finalize (GObject *object)
 		g_free (etc->text);
 	etc->text = NULL;
 	
-	parent_class->finalize (object);
+	parent_class->dispose (object);
+}
+
+static void
+etc_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
+{
+	ETableCol *etc = E_TABLE_COL (object);
+
+	switch (prop_id) {
+	case PROP_COMPARE_COL:
+		etc->compare_col = g_value_get_int (value);
+		break;
+	default:
+		break;
+	}
+}
+
+static void
+etc_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
+{
+	ETableCol *etc = E_TABLE_COL (object);
+
+	switch (prop_id) {
+	case PROP_COMPARE_COL:
+		g_value_set_int (value, etc->compare_col);
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+		break;
+	}
 }
  
 static void
-etc_set_arg (GtkObject *o, GtkArg *arg, guint arg_id)
+e_table_col_class_init (GObjectClass *object_class)
 {
-	ETableCol *etc = E_TABLE_COL (o);
-	
-	switch (arg_id){
-	case ARG_SORTABLE:
-		etc->sortable = GTK_VALUE_BOOL(*arg);
-		break;
-	}
-}
+	parent_class = g_type_class_peek_parent (object_class);
 
-static void
-etc_get_arg (GtkObject *o, GtkArg *arg, guint arg_id)
-{
-	ETableCol *etc = E_TABLE_COL (o);
-	
-	switch (arg_id){
-	case ARG_SORTABLE:
-		GTK_VALUE_BOOL(*arg) = etc->sortable;
-		break;
-	default:
-		arg->type = GTK_TYPE_INVALID;
-		break;
-	}
-}
-     
-static void
-e_table_col_class_init (GtkObjectClass *object_class)
-{
-	parent_class = gtk_type_class (PARENT_TYPE);
-	object_class->get_arg = etc_get_arg;
-	object_class->set_arg = etc_set_arg;
+	object_class->dispose = etc_dispose;
+	object_class->set_property = etc_set_property;
+	object_class->get_property = etc_get_property;
 
-	G_OBJECT_CLASS (object_class)->finalize = etc_finalize;
-
-	gtk_object_add_arg_type ("ETableCol::sortable",
-				 GTK_TYPE_BOOL, GTK_ARG_READWRITE, ARG_SORTABLE);  
+	g_object_class_install_property (object_class, PROP_COMPARE_COL,
+					 g_param_spec_int ("compare_col",
+							   _( "Width" ),
+							   "Width", 
+							   0, G_MAXINT, 0,
+							   G_PARAM_READWRITE)); 
 }
 
 static void
@@ -107,7 +109,7 @@ e_table_col_init (ETableCol *etc)
 	etc->priority = 0;
 }
 
-E_MAKE_TYPE(e_table_col, "ETableCol", ETableCol, e_table_col_class_init, e_table_col_init, PARENT_TYPE)
+E_MAKE_TYPE(e_table_col, "ETableCol", ETableCol, e_table_col_class_init, e_table_col_init, G_TYPE_OBJECT)
 
 /** 
  * e_table_col_new:
@@ -148,11 +150,12 @@ e_table_col_new (int col_idx, const char *text, double expansion, int min_width,
 	g_return_val_if_fail (compare != NULL, NULL);
 	g_return_val_if_fail (text != NULL, NULL);
 
-	etc = gtk_type_new (E_TABLE_COL_TYPE);
+	etc = g_object_new (E_TABLE_COL_TYPE, NULL);
        
 	etc->is_pixbuf = FALSE;
 
 	etc->col_idx = col_idx;
+	etc->compare_col = col_idx;
 	etc->text = g_strdup (text);
 	etc->pixbuf = NULL;
 	etc->expansion = expansion;
@@ -165,7 +168,7 @@ e_table_col_new (int col_idx, const char *text, double expansion, int min_width,
 	etc->selected = 0;
 	etc->resizable = resizable;
 
-	gtk_object_ref (GTK_OBJECT(etc->ecell));
+	g_object_ref (etc->ecell);
 
 	return etc;
 }
@@ -208,11 +211,12 @@ e_table_col_new_with_pixbuf (int col_idx, const char *text, GdkPixbuf *pixbuf, d
 	g_return_val_if_fail (compare != NULL, NULL);
 	g_return_val_if_fail (pixbuf != NULL, NULL);
 
-	etc = gtk_type_new (E_TABLE_COL_TYPE);
+	etc = g_object_new (E_TABLE_COL_TYPE, NULL);
 
 	etc->is_pixbuf = TRUE;
 
 	etc->col_idx = col_idx;
+	etc->compare_col = col_idx;
 	etc->text = g_strdup(text);
 	etc->pixbuf = pixbuf;
 	etc->expansion = expansion;
@@ -225,7 +229,7 @@ e_table_col_new_with_pixbuf (int col_idx, const char *text, GdkPixbuf *pixbuf, d
 	etc->selected = 0;
 	etc->resizable = resizable;
 
-	gtk_object_ref (GTK_OBJECT(etc->ecell));
+	g_object_ref (etc->ecell);
 	gdk_pixbuf_ref (etc->pixbuf);
 
 	return etc;
